from optlang.interface import OPTIMAL, INFEASIBLE, TIME_LIMIT, UNBOUNDED

MODEL_ID = 'model_id'
PROTECT = 'mcs_lin'
SUPPRESS = 'mcs_bilvl'
SUPPRESS = 'suppress'
PROTECT = 'protect'
OPTKNOCK = 'optknock'
ROBUSTKNOCK = 'robustknock'
OPTCOUPLE = 'optcouple'

TIME_LIMIT_W_SOL = TIME_LIMIT + '_w_sols'
ERROR = 'error'

KOCOST = 'ko_cost'
KICOST = 'ki_cost'
GKOCOST = 'gko_cost'
GKICOST = 'gki_cost'
REGCOST = 'reg_cost'

MODULES = 'sd_modules'
MODULE_TYPE = 'module_type'
CONSTRAINTS = 'constraints'
INNER_OBJECTIVE = 'inner_objective'
INNER_OPT_SENSE = 'inner_opt_sense'
OUTER_OBJECTIVE = 'outer_objective'
OUTER_OPT_SENSE = 'outer_opt_sense'
PROD_ID = 'prod_id'
MIN_GCP = 'min_gcp'
MAXIMIZE = 'maximize'
MINIMIZE = 'minimize'
DESIRED = 'desired'
UNDESIRED = 'undesired'
SOLVER = 'solver'
CPLEX = 'cplex'
GUROBI = 'gurobi'
SCIP = 'scip'
GLPK = 'glpk'

SETUP = 'sd_setup'
MAX_SOLUTIONS = 'max_solutions'
MAX_COST = 'max_cost'
T_LIMIT = 'time_limit'
SOLUTION_APPROACH = 'solution_approach'
ANY = 'any'
BEST = 'best'
POPULATE = 'populate'
